@@ -81,7 +81,7 @@
 #' measurements made at the bedside (~1 data point per hour), laboratory test
 #' results, procedures, medications, caregiver notes, imaging reports, and
 #' mortality (both in and out of hospital). For further information, please
-#' refer to the [MIMIC-III documentation](https://mimic.physionet.org/iii/).
+#' refer to the [MIMIC-III documentation](https://mimic.mit.edu/docs/iii/).
 #'
 #' The corresponding
 #' [demo dataset](https://physionet.org/content/mimiciii-demo/)
@@ -130,6 +130,19 @@
 #' demographic information corresponding to the 20,000 individual patients
 #' is spread over 7 tables.
 #'
+#' @section MIMIC-IV:
+#' With the recent v1.0 release of MIMIC-IV, experimental support has been
+#' added in `ricu`. Building on the success of MIMIC-III, this next iteration
+#' contains data on patients admitted to an ICU or the emergency department
+#' between 2008 - 2019 at BIDMC. Therefore, relative to MIMIC-III, patients
+#' admitted prior to 2008 (whose data is stored in a CareVue-based system) has
+#' been removed, while data onward of 2012 has been added. This simplifies
+#' data queries considerably, as the CareVue/MetaVision data split in MIMIC-III
+#' no longer applies. While addition of ED data is planned, this is not part
+#' of the initial v1.0 release and currently is not supported by `ricu`. For
+#' further information, please refer to the [MIMIC-III documentation
+#' ](https://mimic.mit.edu/docs/iii/).
+#'
 #' @format
 #' The exported `data` environment contains all datasets that have been made
 #' available to `ricu`. For datasets that are attached during package loading
@@ -175,6 +188,15 @@
 #' Elbers, Dr. P.W.G. (Amsterdam UMC) (2019): AmsterdamUMCdb v1.0.2. DANS.
 #' https://doi.org/10.17026/dans-22u-f8vd
 #'
+#' Johnson, A., Bulgarelli, L., Pollard, T., Horng, S., Celi, L. A., & Mark, R.
+#' (2021). MIMIC-IV (version 1.0). PhysioNet.
+#' https://doi.org/10.13026/s6n6-xd98.
+#'
+#' Goldberger, A., Amaral, L., Glass, L., Hausdorff, J., Ivanov, P. C., Mark,
+#' R., ... & Stanley, H. E. (2000). PhysioBank, PhysioToolkit, and PhysioNet:
+#' Components of a new research resource for complex physiologic signals.
+#' Circulation (Online). 101 (23), pp. e215–e220.
+#'
 #' @encoding UTF-8
 #' @rdname data_env
 #' @export
@@ -204,6 +226,10 @@ NULL
 #' @rdname data_env
 NULL
 
+#' @name miiv
+#' @rdname data_env
+NULL
+
 data_env <- function() get("data", envir = pkg_env(), mode = "environment")
 
 #' Data source environments
@@ -237,7 +263,7 @@ data_env <- function() get("data", envir = pkg_env(), mode = "environment")
 #' with `src_env` objects. This allows certain functionality, for example data
 #' loading, to be adapted to data source-specific requirements.
 #'
-#' Instantiation and set up of `src_env` objects is possible irrespectively of
+#' Instantiation and set up of `src_env` objects is possible irrespective of
 #' whether the underlying data is available. If some (or all) data is missing,
 #' the user is asked for permission to download in interactive sessions and an
 #' error is thrown in non-interactive sessions upon first access of a
@@ -563,7 +589,7 @@ safe_tbl_get <- function(x, env) {
 
   tryCatch(
     get0(x, envir = env, inherits = FALSE),
-    miss_tbl_msg = function(msg) NULL
+    miss_tbl_msg = function(msg) msg[["tbl_cfg"]]
   )
 }
 
